﻿# You can place the script of your game in this file.
init:
    python:

        import math

        class Shaker(object):

            anchors = {
                'top' : 0.0,
                'center' : 0.5,
                'bottom' : 1.0,
                'left' : 0.0,
                'right' : 1.0,
                }

            def __init__(self, start, child, dist):
                if start is None:
                    start = child.get_placement()
                #
                self.start = [ self.anchors.get(i, i) for i in start ]  # central position
                self.dist = dist    # maximum distance, in pixels, from the starting point
                self.child = child

            def __call__(self, t, sizes):
                # Float to integer... turns floating point numbers to
                # integers.
                def fti(x, r):
                    if x is None:
                        x = 0
                    if isinstance(x, float):
                        return int(x * r)
                    else:
                        return x

                xpos, ypos, xanchor, yanchor = [ fti(a, b) for a, b in zip(self.start, sizes) ]

                xpos = xpos - xanchor
                ypos = ypos - yanchor

                nx = xpos + (1.0-t) * self.dist * (renpy.random.random()*2-1)
                ny = ypos + (1.0-t) * self.dist * (renpy.random.random()*2-1)

                return (int(nx), int(ny), 0, 0)

        def _Shake(start, time, child=None, dist=100.0, **properties):

            move = Shaker(start, child, dist=dist)

            return renpy.display.layout.Motion(move,
                          time,
                          child,
                          add_sizes=True,
                          **properties)

        Shake = renpy.curry(_Shake)
    
    # Declare images below this line, using the image statement.
    # eg. image eileen happy = "eileen_happy.png"
    image bg shop = "shop.jpg"
    image bg table = "cirno_corner.jpg"
    image bg forest = "forest.png"
    image bg shrine = "shrine.png"
    image bg mistylake = "mistylake.png"
    
    image rinnosuke bored = "rinnosuke_bored.png"
    image rinnosuke normal = "rinnosuke_normal.png"
    
    image cirno alert = "cirno_alert.png"
    image cirno beat = "cirno_beat.png"
    image cirno happy = "cirno_happy.png"
    image cirno mad = "cirno_mad.png"
    image cirno normal = "cirno_normal.png"
    image cirno shock = "cirno_shock.png"
    image cirno smile = "cirno_smile.png"
    image cirno strike = "cirno_strike.png"
    image cirno sweat = "cirno_sweat.png"
    
    image mystia alert = "mystia_alert.png"
    image mystia normal = "mystia_normal.png"
    image mystia sob = "mystia_sob.png"
    image mystia mad = "mystia_mad.png"
    
    image reimu alert = "reimu_alert.png"
    image reimu wink = "reimu_wink.png"
    image reimu happy = "reimu_happy.png"
    image reimu mad = "reimu_mad.png"
    image reimu smile = "reimu_smile.png"
    image reimu sweat= "reimu_sweat.png"
    image reimu think= "reimu_think.png"
    image reimu what = "reimu_what.png"
    image reimu attack = "ded.jpg"
    
    image marisa frown= "marisa_frown.png"
    image marisa happy= "marisa_happy.png"
    image marisa mad= "marisa_mad.png"
    image marisa shy = "marisa_shy.png"
    image marisa sly= "marisa_sly.png"
    image marisa smile= "marisa_smile.png"
    image marisa sweat= "marisa_sweat.png"
    
    # Declare characters used by this game.
    $ ri = Character('Rinnosuke', color="#ffffff")
    $ c = Character('Cirno', color="#0000f0")
    $ l = Character('Mystia', color="#00f000")
    $ r = Character('Reimu', color="#f00000")
    $ m = Character('Marisa', color="#fff000")
    
    # oh baby I can define my own shit too wooo!
    $ quickdissolve = Dissolve(0.2)

# The game starts here.
label start:

    play music "maintheme.mp3"
    
    scene bg shop
    with fade
    
    "Rinnosuke sat in his shop one afternoon, flipping disinterestedly through Bunbunmaru newspaper."
    show rinnosuke bored at right
    with dissolve
    ri "Blah blah blah …{w} man, {w}there's nothing in this thing."
    ri "It's like the tengu isn't even trying to make anything up anymore."
    ri "This is all …{w} just regular news."
    "Rinnosuke sighed."
    ri "Well, might as well try and straighten up around here a little."
    hide rinnosuke bored
    with dissolve
    "Stepping out from behind the counter, he looked at the cluttered shelves, {w}the tables piled high with books, toys, and various bric-a-brac."
    "He shook his head at the state of things."
    "How did he let it get away from him like this?"
    "Well, nothing to it but to do it, he decided."
    "The first thing to do, he figured, would be to make some floor space for sorting things."
    "So he took hold of one side of a table and began to push it towards the wall, but it was quite a struggle from the weight of thing."
    "Cirno happily jaunted in."
    show cirno happy at left
    with dissolve
    c "Hiya, old man!"
    "She chirped with a wave of her hand."
    c "Ya need any help today?"
    "Rinnosuke sighed again."
    "Lately Cirno had been stopping by out of sheer boredom, hanging out for hours on end, talking and talking, about nothing at all, under the guise of “helping around the shop”. "
    show rinnosuke normal at right
    with dissolve
    ri "No, thank you, Cirno, I think I can manage."
    show cirno smile
    with quickdissolve
    c "Nuh uh!"
    # "said Cirno teasingly"
    show cirno happy
    with quickdissolve
    c "You can't even move that table by yourself."
    show cirno smile
    with quickdissolve
    c "Lemme give ya a hand."
    "She stepped towards the table."
    ri "No, really, Cirno, it's alright."
    # "Insisted Rinnosuke, annoyed."
    show cirno mad
    with quickdissolve
    c "Ah c'mon!"
    # "she whined"
    show cirno happy
    with quickdissolve
    c "I'm the strongest in Gensokyo!"
    show cirno strike
    with quickdissolve
    c "Lemme do it!"
    "Taking hold of a corner of the table, she began to push it anyway."
    ri "Fine."
    # "said Rinnosuke, walking away,"
    ri "You can do it yourself then."
    hide rinnosuke normal
    with quickdissolve
    "He stepped behind the counter, and walked through the curtains to his room."
    show cirno happy
    with quickdissolve
    c "You got it, old man!"
    # "piped Cirno, and gripped the table corner with grim determination."
    "She gripped the table corner with grim determination."
    show cirno strike
    with quickdissolve
    c "Alright table. You met your match now!"
    "Cirno began to push, but it was heavier than she thought."
    show cirno sweat
    with quickdissolve
    c "Urgh."
    show cirno smile
    with quickdissolve
    c "Gonna be difficult, eh?"
    show cirno strike
    with quickdissolve
    c "Well, we'll see about that!"
    "Putting more of her weight into it, the table moved a little."
    "Encouraged, Cirno moved closer to the table corner, leaning her body against it, and pushed." 
    "The table groaned as it scraped across the floor surface."
    stop music
    show cirno alert
    with quickdissolve
    "Cirno stopped."
    "What was this sensation she felt, {w}where the table corner pressed against her, between her legs?"
    show cirno strike
    with quickdissolve
    "She pushed again."
    show cirno shock
    with quickdissolve
    c "Oh wow."
    # "she gasped."
    "It felt kind of good."
    show cirno strike
    with quickdissolve
    play sound "cloth.wav"
    "Cautiously, she started to rub her crotch against the corner of the table. It started to feel even better."

    # unf unf unf
    scene bg table
    with fade
    c "What's this?"
    # "she giggled."
    c "What's this?"
    c "Ahahahaha!"
    play sound "cloth.wav"
    "Cirno rubbed her crotch against the table corner faster."
    "She could not believe how good this felt."
    "What an amazing discovery!"
    "She'd never seen anyone else do this before, or even talk about it."
    "Could it be that she, the one everyone in Gensokyo teased as being stupid, had discovered something no one else knew about it?"
    "This made her even more excited."
    "She rubbed faster, harder, the pleasure growing."
    c "R-Rinnosuke!"
    # "she called out."
    c "C'm'ere! You gotta see this!"
    "Rinnosuke stepped slowly out from behind the curtains."
    ri "What is it this time, Cir-"
    "and stopped in his tracks, stunned, watching Cirno furiously rubbing her crotch against the corner of the table."
    c "You got to try this!"
    # "Cirno beamed, her face flushed."
    c "It feels amaaaaaazing!"
    "Rinnosuke turned bright red."
    "She might be as old as an elderly human, but in her mind she's like a child."
    "I can't scold her for this, he thought.{w} She doesn't know any better."
    ri "Uh,{w=0.5} Cirno,{w=0.5} um,{w=0.5} I just remembered I ….{w=1} have an appointment.{w=0.5} Yes.{w=0.5} So I need to close the shop."
    play sound "cloth.wav"
    "Cirno kept riding the table corner, faster."
    c "Now? Right now?"
    "Her eyes pleaded in protest."
    ri "Right now."
    # "Rinnosuke stammered"
    ri "So get out.{w} Now."
    c "But-"
    ri "Out!"
    stop sound
    
    scene bg shop
    with fade
    "Cirno let go of the table, panting."
    show cirno mad at left
    with dissolve
    c "Fine!"
    # "she pouted."
    "Rinnosuke escorted her to the door, practically shoving her out, and locked the door behind her."
    
    scene bg forest
    with fade
    play music "forest.wav"
    show cirno sweat with quickdissolve
    "Cirno stood in the afternoon light, her crotch throbbing, tingling."
    "The old man was too wrapped up in his own affairs to even acknowledge her amazing discovery."
    "No one would believe her if she told them."
    "Well, almost no one."
    "Mystia might."
    show cirno smile
    with quickdissolve
    "She'd have to show her this."
    "She smiled when she realized this,{w} but then remembered the shop was closed, for who knows how long."
    show cirno alert
    with quickdissolve
    "Last time it was closed for a week."
    show cirno mad
    with quickdissolve
    "She cursed the situation."
    "I can't wait that long, she decided."
    "I have to find some other place that has a table."
    show cirno strike
    with quickdissolve
    "Determined to show off her discovery, she flew off into the sky."
    stop music
    
    scene bg shrine
    with Fade(.5, .5, .5)
    play music "shrine.mp3"
    "Mystia and Cirno flew towards Hakurei Shrine that evening."
    "As luck would have it, Cirno saw that Reimu was just leaving, on her way into the woods."
    show cirno smile at left
    with dissolve
    c "Perfect!"
    # "giggled Cirno."
    c "That lazy shrine maiden won't try and challenge me."
    "Mystia only tagged along because she had nothing better to do, but was still trepidacious."
    show mystia sob at right
    with dissolve
    l "Um, what exactly are we doing here, anyway?"
    c "You'll see."
    # "grinned Cirno, and flew down to the shrine."
    "Cirno grinned, and flew down to the shrine."
    hide cirno with dissolve
    "Mystia followed."
    hide mystia with dissolve
    "They landed deftly on the front steps. {w}Mystia looked around cautiously."
    "She'd seen Reimu leave, but she was still worried about being caught."
    show mystia mad at right
    with dissolve
    l "Cirno!"
    # "she whispered,"
    l "We really shouldn't be here."
    show mystia sob
    with quickdissolve
    l "We could get in big trouble!"
    show cirno smile at left
    with dissolve
    c "Oh shush."
    # "chided Cirno."
    c "You're such a baby."
    show mystia mad
    with quickdissolve
    l "You're the baby!"
    show cirno mad
    with quickdissolve
    c "Am not! You are!"
    l "You are!"
    show cirno sweat
    with quickdissolve
    "Cirno sighed."
    show cirno smile
    with quickdissolve
    c "Look, we won't be long, alright? {w}Stop worrying."
    show mystia sob
    with quickdissolve
    l "Fine."
    show cirno normal
    with quickdissolve
    "Mystia looked around her again."
    show mystia normal
    with quickdissolve
    l "So, what did you want to show me, anyway?"
    show cirno smile
    with quickdissolve
    "Cirno smiled conspiratorily, and stepped up to the donation box."
    c "Watch."
    play sound "cloth.wav"
    "Cirno took hold of the corner of the donation box, and started to rub her crotch against it."
    show cirno shock with quickdissolve
    "This felt even better than the table!"
    "But why?"
    "Maybe because of the wooden studs around the edge?"
    show cirno smile with quickdissolve
    "She didn't care."
    "She rubbed faster."
    "Mystia watched, confused."
    l "What are you doing?"
    # "Then she looked terrified."
    show mystia mad with quickdissolve
    l "Wait, {w}you're not trying to steal the donation box, are you?"
    l "I mean, you know there's nothing in that thing."
    show cirno sweat with quickdissolve
    c "I'm … {w}not trying to … {w}steal it."
    "Cirno stammered between breaths."
    show cirno smile with quickdissolve
    c "It feels good! {w}C'mon, {w}try it!"
    show mystia normal with quickdissolve
    l "What?"
    c "Just try it! {w}You'll see."
    "Wary, Mystia approached the opposite corner of the donation box."
    l "OK ..."
    play sound "cloth.wav"
    "She took hold of the corner, and imitated Cirno, tentatively rubbing her crotch against the corner."
    c "Do it faster!"
    # "encouraged Cirno."
    "Mystia moved faster."
    show mystia alert
    with quickdissolve
    "Her eyes widened with surprise."
    l "Oh wow!"
    c "I know!"
    l "This is … {w}wow …"
    show mystia normal
    with quickdissolve
    "Mystia rubbed against the corner with greater vigor."
    show mystia alert
    with quickdissolve
    l "This is reeeally nice."
    c "Mhmm!"
    "Together, the two of them gripped either side of the donation box as they rubbed their crotches against opposite corners, panting."
    l "Cirno."
    # "breathed Mystia, an ecstatic grin on her face"
    l "You … {w}are … {w}a genius."
    show cirno happy
    with quickdissolve
    "Cirno beamed."
    "She was a genius,{w} she really was."
    "Soon everyone in Gensokyo would respect her."
    "No one would tease her anymore."
    stop sound
    
    scene bg forest
    with fade
    "Reimu stepped out of the woods, having forgotten to bring the ribbons Marisa asked for, and noticed shadows moving in front of the shrine."
    show reimu alert at left with dissolve
    r "Where the donation box is – {w}thieves!"
    show reimu mad with quickdissolve
    "Furious, Reimu decided to surprise them."
    "Stepping back into the woods, she circled around, behind the shrine."
    r "The nerve!"
    r "I step away for one minute, and some dirty thieves come and try and rob me."
    show reimu think with quickdissolve
    "Quietly, she stalked into the rear entrance, stepping gingerly across the floor."
    "She could hear the thieves panting, struggling to lift the donation box."
    "Their silhouettes showed from behind the screen."
    show reimu wink with quickdissolve
    r "Weaklings."
    r "This is going to be fun."
    "She approached the screen, took hold of the edge, and slowly slid it open."
    hide reimu with dissolve
    stop music
    
    scene black with CropMove(0.5, "wiperight")
    "There are plenty of things Reimu had seen in her life."
    "She'd watched a red mist cover Gensokyo."
    "She'd seen the real moon replaced by a fake one."
    "She'd even seen a crow swallow a sun and turn into a maniac hell-bent on conquering."
    "But until she saw a night sparrow and an ice fairy each simultaneously having sexual relations with her donation box, {w}she thought she'd seen it all."
    "This, this right here – {w}this was too much."
    
    play sound "slidingdoor.wav"
    scene bg shrine with CropMove(0.5, "wiperight")
    "Reimu slammed the screen open."
    "Cirno and Mystia froze and gasped, still gripping the box."
    "Time seemed to stop."
    "Somewhere in the woods, {w}a frog croaked."
    show reimu what with quickdissolve
    "Reimu, bright red with embarrassment and anger, shaking, took a deep breath and bellowed."
    with Shake((0, 0, 0, 0), 0.5, dist=20)
    "W-What the {b}hell{/b} are you {b}perverts{/b} doing?!"
    hide reimu with quickdissolve
    show mystia alert at right with quickdissolve
    show cirno shock at left with quickdissolve
    l "We- {w}We were just..."
    "But there was no time for words."
    "Reimu had already spun, and produced a spell card."
    play music "youarealreadydead.mp3"
    play sound "se_cat00.wav"
    show reimu attack with quickdissolve
    r "SHAMEFUL ARTS {w=1.0}'OMNIDIRECTIONAL {w=1.0}PERVERT {w=1.0}SLAYING {w=1.0}CIRCLE!!!'"
    play sound "se_tan00.wav"
    "Reimu declared, and let loose with a barrage of danmaku the likes of which they'd never seen."
    "They never had a chance."
    play sound "se_enep01.wav"
    with Shake((0, 0, 0, 0), 3.0, dist=40)
    
    scene bg forest with CropMove(0.5, "slidedown")
    play sound "thud.wav"
    with Shake((0, 0, 0, 0), 0.5, dist=20)
    play sound "thud.wav"
    with Shake((0, 0, 0, 0), 0.5, dist=20)
    "Mystia and Cirno were blown into the woods with the power of Reimu's anger, utterly defeated."
    show mystia sob at right with dissolve
    l "Waaah!"
    l "Cirno you dummy! {w}I knew we were going to get caught!"
    show cirno beat at left with dissolve
    c "Shut up."
    c "You're such a baby."
    l "I am not!"
    "Cirno sighed. {w}Now what was she going to do?"
    
    play music "theme2.mp3" fadeout 1
    scene bg shrine with Fade(.5, .5, .5)
    show marisa sweat at right with quickdissolve
    m "Wow."
    "Marisa took another sip of tea."
    show marisa smile with quickdissolve
    m "That's pretty disturbing."
    show reimu sweat at left with dissolve
    r "I know."
    "Reimu sighed while sitting on the floor, resting her head against her wall."
    r "I had that spellcard saved for the tengu. {w}I never thought I'd have to use it on those two."
    show marisa sweat with quickdissolve
    m "Yeah, that is pretty … wow. {w}Are you sure they were-"
    show reimu mad with quickdissolve
    r "They were. {w}Like dogs in heat."
    "Marisa gave a low whistle, then shook her head."
    m "How on earth did they … {w}I mean, how did they decide to … {w}I … {w}I'm speechless."
    "Reimu sighed, and took a sip of tea."
    show reimu think with quickdissolve
    r "It can't be helped. {w}I guess they're growing up."
    "Marisa nodded."
    show marisa smile with quickdissolve
    m "Yeah, I guess so, ze."
    show marisa shy with quickdissolve
    m "But I mean, I never … you know … like that."
    show marisa sly with quickdissolve
    m "Did you?"
    "Reimu blushed deep red."
    show reimu mad with quickdissolve
    r "W-What? {w}No, of course not! {w}A shrine maiden doesn't … {w}ugh."
    show marisa sweat with quickdissolve
    m "This is pretty awkward."
    show reimu sweat with quickdissolve
    r "Yeah."
    show marisa frown with quickdissolve
    m "I'm not going to be able to look at those two the same."
    show reimu mad with quickdissolve
    r "Me neither. Or my donation box. My poor, poor donation box."
    show reimu sweat with quickdissolve
    show marisa sweat with quickdissolve
    "Marisa and Reimu sat in silence for a few beats."
    "Marisa thought about it."
    show marisa sly with quickdissolve
    m "You know what I used to do?"
    "Reimu closed her eyes and held up her hand."
    show reimu mad with quickdissolve
    r "I don't even want to know. {w}Please. {w}I've had enough perverts for one day."
    "Marisa chuckled."
    show marisa happy with quickdissolve
    m "Jeez, you're such a prude, ze. Lighten up."
    "Marisa thought some more about it."
    show marisa sly with quickdissolve
    "And then she got an idea. {w}A wonderful, {w}terrible idea."
    "She stood up."
    show marisa happy with quickdissolve
    m "Well, I'm gonna get going. {w}Catch ya later, ze."
    show reimu think with quickdissolve
    "Reimu nodded, still in shock."
    "Marisa chuckled to herself as she flew off."
    hide reimu with dissolve
    show marisa smile with quickdissolve
    "For a girl who's gone head-to-head with goddesses, she sure is easy to rattle."
    "Marisa flew over the treetops for the Misty Lake."
    
    play music "lake.mp3" fadeout 1
    scene bg mistylake with Fade(.5, .5, .5)
    show cirno beat at left with quickdissolve
    "Cirno gave up."
    "Slumping down on the ground, she frowned at the tree stump, and gave it a frustrated kick."
    "It just wasn't the same."
    "She had to have the donation box."
    "But Reimu was so angry at her."
    "Why?"
    "Why was Reimu so mean?"
    "I wasn't hurting anyone."
    "I wasn't trying to steal the donation box."
    "So why did she attack me?"
    "Why is everyone so mean to me?"
    "Cirno could feel tears welling up, and wiped them from her eyes with the back of her hand."
    "She wanted to run away and not see anyone, ever again."
    "Cirno stood up, brushing the pieces of bark from her dress. {w}Stupid tree stump."
    show cirno alert with quickdissolve
    "She heard something drop with a thud behind her."
    show marisa smile at right with quickdissolve
    "Quickly, she turned around, and saw Marisa there, smiling."
    "Cirno was struck with panic, but wasn't about to show it."
    c "Marisa... {w}What are you doing here?"
    show marisa happy with quickdissolve
    m "Ah, ya know, just payin' a visit, ze."
    "Marisa stepped closer."
    show cirno strike with quickdissolve
    c "Back off!"
    c "I-I'll fight you, you know! {w}I'm not afraid of you."
    "Marisa laughed casually."
    m "Cirno, {w}relax. {w}I'm not gonna hurt you, alright? {w}I wanna talk with you."
    show cirno sweat with quickdissolve
    "Cirno paused."
    "Marisa seemed to mean it."
    "But could she trust her?"
    c "W-What about?"
    show marisa sweat with quickdissolve
    m "Look, uh..."
    "Marisa rubbed the back of her neck with embarrassment."
    show marisa smile with quickdissolve
    m "Hm, how should I put this? {w}Well, I uh talked to Reimu. {w}About what you and Mystia were doing."
    c "OK …?"
    "Cirno paused."
    c "Are we in trouble?"
    show marisa sweat with quickdissolve
    "Marisa shook her head."
    show marisa happy with quickdissolve
    m "No, you're not in trouble. {w}What you guys were doing is … {w}well, {w}it's natural, ze. {w}Ya see ..."
    "Marisa put her hand on Cirno's shoulder, comfortingly."
    show marisa sweat with quickdissolve
    m "Hm. {w}Never thought I'd have this talk with you. {w}Heh."
    show marisa happy with quickdissolve
    m "Well, {w}you're growing up. {w}Alright? {w}And when you grow up, you start to get these … {w}urges."
    show marisa smile with quickdissolve
    m "That's what that … {w}stuff you were doing was about. {w}Satisfying urges."
    show cirno shock with quickdissolve
    "Cirno looked aghast."
    c "You mean … {w}I didn't think that up myself?"
    show marisa shy with quickdissolve
    "Marisa blinked. {w}That's what she's concerned about?"
    show marisa sweat with quickdissolve
    m "Well, I mean, touching yourself … {w}there … {w}starts to feel good when you grow up. {w}So plenty of people do it."
    show marisa happy with quickdissolve
    m "But I gotta admit I'd never seen or heard of anyone doing it that way before, {w}so in a way, yeah."
    show marisa smile with quickdissolve
    m "I guess you could say you thought it up yourself."
    "Marisa ruffled Cirno's hair."
    show marisa happy with quickdissolve
    m "Not so dumb after all, are ya, ze?"
    show cirno happy with quickdissolve
    "Cirno blushed, but couldn't help but smile."
    c "I told you guys I was smart!"
    show marisa sweat with quickdissolve
    m "Yeah, yeah. Anyway."
    show marisa sly with quickdissolve
    m "You think that feels good?"
    "Marisa grinned wickedly, and then held up the end of her broom."
    show marisa happy with quickdissolve
    m "Wait'll ya try {b}this!{/b}"
    
    play music "theme2.mp3" fadeout 0.5
    scene bg shrine with quickdissolve
    show reimu what at left with quickdissolve
    r "You did {b}what?!{/b}"
    "Reimu slumped down on the top steps of the shrine, pale, her jaw dropped open."
    show marisa happy at right with quickdissolve
    "Marisa still couldn't stop laughing, stretching her legs out on the steps as she leaned back and smiled."
    show marisa sly with quickdissolve
    m "I showed her my way, that's all, ze. {w}What's the big deal?"
    r "I can't believe I'm hearing this."
    "Reimu mumbled, her eyes staring into space, unblinking."
    show marisa happy with quickdissolve
    m "Ah, c'mon. {w}Not everyone's like you, ya know."
    show reimu mad with quickdissolve
    "Reimu glared at Marisa."
    r "Maybe more people should be."
    show marisa smile with quickdissolve
    "Marisa waved at her dismissively."
    show marisa sly with quickdissolve
    m "She loved it. {w}Loved. {w}It. {w}She said she couldn't wait to show Mystia."
    "Reimu shuddered, {w}then looked at Marisa's broom, deplored."
    show reimu what with quickdissolve
    r "Oh. Oh no. That's not the same one you-"
    show marisa smile with quickdissolve
    m "Nah."
    show marisa happy with quickdissolve
    m "I let her have that one. This is a different one. I got like twenty of these things at home, ze."
    show marisa sly with quickdissolve
    m "You don't think I fly with the same one all the time, do you?"
    show reimu sweat with quickdissolve
    r "Well, no, I guess that-"
    show marisa happy with quickdissolve
    m "And look at it this way: {w}they won't be back to molest your donation box again. So it's a blessing, really, ze."
    "Reimu sighed."
    show reimu think with quickdissolve
    r "I suppose. Still …"
    show reimu sweat with quickdissolve
    "Reimu shook her head, staring into the woods. {w}Why was everyone around her so weird?"
    r "But Marisa … you? I never thought you'd … ugh, I don't even want to think about it."
    show marisa sly with quickdissolve
    m "You sure?"
    show marisa happy with quickdissolve
    m "You could stand to loosen up, ya know. {w}It'd be my pleasure to show you-"
    show reimu mad with quickdissolve
    r "Get out."
    m "I mean, probably more like your pleasure-"
    r "Out!"
    show marisa sly with quickdissolve
    m "Trust me, it's like sake. {w}Once you have a taste you can never-"
    show reimu what with quickdissolve
    with Shake((0, 0, 0, 0), 0.2, dist=10)
    r "GET!"
    with Shake((0, 0, 0, 0), 0.2, dist=10)
    r "OUT!"
    "Reimu shrieked, plugging her ears with her fingers."
    show marisa sweat with quickdissolve
    m "Alright, alright, don't get so bent outta shape, ze."
    m "Jeez. Some people."
    "She mounted her broom and flew off."
    show marisa happy with quickdissolve
    m "See ya!"
    hide marisa with dissolve
    show reimu think with quickdissolve
    "Reimu stared into the woods."
    "Sake isn't a bad idea right now, she decided."
    "Whatever it takes to forget this day ever happened."

    jump credits
    
    
label credits:

    scene black with Fade(1, .5, 1)
    play music "credits.mp3" fadeout 1
    "The End"
    "(lazily done) Credits"
    "Programming and putting-everything-together-in-general by Suikama"
    "Story written by Tengukami"
    "Graphics by Tasofro and uh... {w}other random artists on danbooru :V"
    "Background music by Tasofro"
    "Sound effects from Touhou, Umineko, and freesound.org"
    "That's all folks!"
    
    
    
    return
